/*
 *   Copyright (c) 1999-2004 eVelopers Corporation. All rights reserved.
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
 */
package com.evelopers.unimod.log;

/**
 * Interface for loggin system. All components should take this
 * interface on create and use it for logging.
 * Actual implementations may use Log4J or another underlying log system.
 *
 * @author kex
 * @author magus
 * @version $Revision: 2$
 */
public interface Logger {

	/**
	 * Empty logger. Simply scrip all log messages.
	 */
	public static Logger EMPTY = new Empty();

	/**
	 * Simple console logger. Use System.out and System.err for logging.
	 */
	public static Logger CONSOLE = new Console();

	/**
	 * Empty logger implementation.
	 */

	public static class Empty implements Logger {

		private Empty() {}

		public Logger getLogger(String name) {
			return this;
		}

		public Logger getLogger(Class clazz) {
			return this;
		}

		public void info(Object message) {}

		public void warn(Object message) {}

		public void debug(Object message) {}

		public void error(Object message) {}

		public void fatal(Object message) {}
	}

	/**
	 * Console logger implementation
	 */
	public static class Console implements Logger {

		private Console() {}

		public Logger getLogger(String name) {
			return this;
		}

		public Logger getLogger(Class clazz) {
			return this;
		}

		public void info(Object message) {
			System.out.println(" [info] " + message);
		}

		public void warn(Object message) {
			System.out.println(" [warn] " + message);
		}

		public void debug(Object message) {
			System.out.println("[debug] " + message);
		}

		public void error(Object message) {
			System.err.println("[error] " + message);
		}

		public void fatal(Object message) {
			System.err.println("[fatal] " + message);
		}
	}

	/**
	 * Returns another logger for given name.
	 *
	 * @param name new logger name
	 * @return newly created logger
	 */
	public Logger getLogger(String name);

	/**
	 * Returns another logger for given class.
	 *
	 * @param clazz class to return logger for
	 * @return newly created logger
	 */
	public Logger getLogger(Class clazz);

	/**
	 * Logs info message
	 *
	 * @param message message to log
	 */
	public void info(Object message);

	/**
	 * Logs warning message
	 *
	 * @param message message to log
	 */
	public void warn(Object message);

	/**
	 * Logs debug message
	 *
	 * @param message message to log
	 */
	public void debug(Object message);

	/**
	 * Logs error message
	 *
	 * @param message message to log
	 */
	public void error(Object message);

	/**
	 * Logs fatal message
	 *
	 * @param message message to log
	 */
	public void fatal(Object message);

}
